#include "testApp.h"

//--------------------------------------------------------------
void testApp::setup(){
	
	// load the default ofxOpenNI config settings
	// see bin/data/openni/config/ofxopenni_config.xml
	context.setupUsingXMLFile();
	
	// uncomment this to see what open ni is doing inside
	//context.enableLogging(OF_LOG_VERBOSE);
	
	// setup resources
	depth.setup(&context);
	image.setup(&context);
	user.setup(&context, &depth);
	
	bHijackMouse = true;

}

//--------------------------------------------------------------
void testApp::update(){
	ofBackground(100, 100, 100);
	
	// update the open ni context and user tracker
	context.update();
	user.update();
	
	// Find tracked user
	userId = -1;
	for(int i = 0; i < user.getNumTrackedUsers(); ++i) {
		ofxTrackedUser* tracked = user.getTrackedUser(i);
		if(tracked != NULL)
			if (tracked->neck.begin.x && tracked->neck.begin.y && tracked->neck.begin.x)
			{
				userId = i;
				break;
			}
	}
	// Get hands colors
	if (userId >= 0)
	{
		// sahe habds
		ofxTrackedUser* tracked = user.getTrackedUser(userId);
		leftHand = tracked->left_lower_arm.end;
		rightHand = tracked->right_lower_arm.end;
		leftHandColor = depth.getPixel( leftHand.x, leftHand.y );
		rightHandColor = depth.getPixel( rightHand.x, rightHand.y );
		// find active hand
		if (leftHand.z < rightHand.z)
		{
			activeHand = leftHand;
			inactiveHand = rightHand;
		}
		else
		{
			activeHand = rightHand;
			inactiveHand = leftHand;
		}
		// Make mouse pos
		CGFloat progX = ( activeHand.x / 640.0);
		CGFloat progY = ( activeHand.y / 640.0);
		if (progX < 0.0)
			progX = 0.0;
		else if (progX > 1.0)
			progX = 1.0;
		if (progY < 0.0)
			progY = 0.0;
		else if (progY > 1.0)
			progY = 1.0;
		if (bHijackMouse)
		{
			mousePoint = CGPointMake( ofGetScreenWidth() * progX, ofGetScreenHeight() * progY );
			CGDisplayMoveCursorToPoint(CGMainDisplayID(), mousePoint);
		}
	}
}

//--------------------------------------------------------------
void testApp::draw(){
	
	ofSetColor(ofColor(255,255,255));

	// draw depth and rgb images
	depth.draw();
	image.draw(645, 10, 400, 300);
	
	// draw all the users automatically?
	user.draw();
	
	stringstream info;
	info << "number of tracked users: " << user.getNumTrackedUsers() << endl << endl;
	
	// draw the neck positions of each user
	int y = 500;
	for(int i = 0; i < user.getNumTrackedUsers(); ++i)
	{
		ofxTrackedUser* tracked = user.getTrackedUser(i);
		if(tracked != NULL)
		{
			if (tracked->neck.begin.x  && tracked->neck.begin.y && tracked->neck.begin.z)
				info << i 
					<< " neck: "
					<< ofToString(tracked->neck.begin.x,0) << " " 
					<< ofToString(tracked->neck.begin.y,0) << " "
					<< ofToString(tracked->neck.begin.z,0) << endl
					<< "  left: "
					<< ofToString(leftHand.x,0) << " " 
					<< ofToString(leftHand.y,0) << " "
					<< ofToString(leftHand.z,0) << endl 
					<< " right: "
					<< ofToString(rightHand.x,0) << " " 
					<< ofToString(rightHand.y,0) << " "
					<< ofToString(rightHand.z,0) << endl << endl; 
		}
		// hand color rects
		ofSetColor(leftHandColor);
		ofRect(300, y, 200, 100);
		ofSetColor(rightHandColor);
		ofRect(550, y, 200, 100);
	}
	ofSetColor(255,255,255);
	ofDrawBitmapString(info.str(), 10, y);
	
	// draw hands
	if (userId >= 0)
	{
		ofSetColor(255,255,0);
		ofCircle(activeHand.x, activeHand.y, 0, 25);
		ofSetColor(255,0,0);
		ofCircle(inactiveHand.x, inactiveHand.y, 0, 10);
	}
}

//--------------------------------------------------------------
void testApp::keyPressed(int key){
	switch (key)
	{
		case ' ':
			bHijackMouse = !bHijackMouse;
			break;
	}

}

//--------------------------------------------------------------
void testApp::keyReleased(int key){

}

//--------------------------------------------------------------
void testApp::mouseMoved(int x, int y ){

}

//--------------------------------------------------------------
void testApp::mouseDragged(int x, int y, int button){

}

//--------------------------------------------------------------
void testApp::mousePressed(int x, int y, int button){

}

//--------------------------------------------------------------
void testApp::mouseReleased(int x, int y, int button){

}

//--------------------------------------------------------------
void testApp::windowResized(int w, int h){

}

